@@ -31,7 +31,6 @@
 #include <telepathy-glib/errors.h>
 #include <telepathy-glib/dbus.h>
 #include <telepathy-glib/svc-connection.h>
-#include <telepathy-glib/svc-unstable.h>
 #include <telepathy-glib/channel-factory-iface.h>
 
 #include <stdio.h>
@@ -70,6 +69,8 @@
 #define IDLE_DEBUG_FLAG IDLE_DEBUG_CONNECTION
 #include "idle-debug.h"
 
+#include "extensions/extensions.h"    /* Renaming */
+
 /* From RFC 2813 :
  * This in essence means that the client may send one (1) message every
  * two (2) seconds without being adversely affected.  Services MAY also
@@ -92,7 +93,7 @@ static void _renaming_iface_init(gpointer, gpointer);
 
 G_DEFINE_TYPE_WITH_CODE(IdleConnection, idle_connection, TP_TYPE_BASE_CONNECTION,
 		G_IMPLEMENT_INTERFACE(TP_TYPE_SVC_CONNECTION_INTERFACE_ALIASING, _aliasing_iface_init);
-		G_IMPLEMENT_INTERFACE(TP_TYPE_SVC_CONNECTION_INTERFACE_RENAMING, _renaming_iface_init));
+		G_IMPLEMENT_INTERFACE(IDLE_TYPE_SVC_CONNECTION_INTERFACE_RENAMING, _renaming_iface_init));
 
 typedef struct _IdleOutputPendingMsg IdleOutputPendingMsg;
 struct _IdleOutputPendingMsg {
@@ -339,7 +340,7 @@ static void idle_connection_class_init (IdleConnectionClass *klass) {
 	GParamSpec *param_spec;
 	static const gchar *interfaces_always_present[] = {
 		TP_IFACE_CONNECTION_INTERFACE_ALIASING,
-		TP_IFACE_CONNECTION_INTERFACE_RENAMING,
+		IDLE_IFACE_CONNECTION_INTERFACE_RENAMING,
 		NULL};
 
 	g_type_class_add_private(klass, sizeof(IdleConnectionPrivate));
@@ -708,7 +709,7 @@ static IdleParserHandlerResult _nick_handler(IdleParser *parser, IdleParserMessa
 		tp_handle_ref(handles, new_handle);
 	}
 
-	tp_svc_connection_interface_renaming_emit_renamed(TP_SVC_CONNECTION_INTERFACE_RENAMING(conn), old_handle, new_handle);
+	idle_svc_connection_interface_renaming_emit_renamed(IDLE_SVC_CONNECTION_INTERFACE_RENAMING(conn), old_handle, new_handle);
 
 	idle_connection_emit_queued_aliases_changed(conn);
 
@@ -937,11 +938,11 @@ static gboolean _send_rename_request(IdleConnection *obj, const gchar *nick, DBu
 	return TRUE;
 }
 
-static void idle_connection_request_rename(TpSvcConnectionInterfaceRenaming *iface, const gchar *nick, DBusGMethodInvocation *context) {
+static void idle_connection_request_rename(IdleSvcConnectionInterfaceRenaming *iface, const gchar *nick, DBusGMethodInvocation *context) {
 	IdleConnection *conn = IDLE_CONNECTION(iface);
 
 	if (_send_rename_request(conn, nick, context))
-		tp_svc_connection_interface_renaming_return_from_request_rename(context);
+		idle_svc_connection_interface_renaming_return_from_request_rename(context);
 }
 
 static void idle_connection_set_aliases(TpSvcConnectionInterfaceAliasing *iface, GHashTable *aliases, DBusGMethodInvocation *context) {
@@ -1027,9 +1028,9 @@ static void _aliasing_iface_init(gpointer g_iface, gpointer iface_data) {
 }
 
 static void _renaming_iface_init(gpointer g_iface, gpointer iface_data) {
-	TpSvcConnectionInterfaceRenamingClass *klass = (TpSvcConnectionInterfaceRenamingClass *) g_iface;
+	IdleSvcConnectionInterfaceRenamingClass *klass = (IdleSvcConnectionInterfaceRenamingClass *) g_iface;
 
-#define IMPLEMENT(x) tp_svc_connection_interface_renaming_implement_##x (\
+#define IMPLEMENT(x) idle_svc_connection_interface_renaming_implement_##x (\
 		klass, idle_connection_##x)
 	IMPLEMENT(request_rename);
 #undef IMPLEMENT
