@@ -1,8 +1,8 @@
 /*
  * This file is part of telepathy-idle
  * 
- * Copyright (C) 2006 Nokia Corporation. All rights reserved.
- *
+ * Copyright (C) 2006-2007 Collabora Limited
+ * Copyright (C) 2006-2007 Nokia Corporation
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License 
@@ -19,17 +19,39 @@
  */
 #include "idle-dns-resolver.h"
 
-#define idle_dns_result_new() \
-	(g_slice_new(IdleDNSResult))
-#define idle_dns_result_new0() \
-	(g_slice_new0(IdleDNSResult))
+#include <sys/types.h>
+#include <sys/socket.h>
+#include <netdb.h>
+
+#define IDLE_DEBUG_FLAG IDLE_DEBUG_DNS
+#include "idle-debug.h"
+
+typedef struct _IdleDNSResultReal IdleDNSResultReal;
+
+struct _IdleDNSResultReal
+{
+  IdleDNSResult result;
+  struct addrinfo *addrinfo;
+};
+
+#define idle_dns_result_real_new() \
+	(g_slice_new(IdleDNSResultReal))
+#define idle_dns_result_real_new0() \
+	(g_slice_new0(IdleDNSResultReal))
 
 void idle_dns_result_destroy(IdleDNSResult *result)
 {
+  IdleDNSResultReal *real = (IdleDNSResultReal *)(result);
+
 	if (result->ai_next)
 	{
 		idle_dns_result_destroy(result->ai_next);
 	}
+
+  if (real->addrinfo)
+  {
+    freeaddrinfo(real->addrinfo);
+  }
 	
 	g_slice_free(IdleDNSResult, result);
 }
@@ -204,7 +226,6 @@ static void sres_answer_callback(sres_context_t *ctx, sres_query_t *query, sres_
 
 	if (!instance)
 	{
-		g_debug("%s: invalid or cancelled context %p, ignoring", G_STRFUNC, ctx);
 		return;
 	}
 
@@ -282,7 +303,6 @@ static void sres_answer_callback(sres_context_t *ctx, sres_query_t *query, sres_
 			break;
 			default:
 			{
-				g_debug("%s: unsupported address family %u encountered, ignoring", G_STRFUNC, answers[i]->sr_record->r_type);
 				continue;
 			}
 			break;
@@ -339,8 +359,6 @@ guint idle_dns_resolver_query(IdleDNSResolver *resolver, const gchar *name, guin
 	static const uint16_t types[] = {sres_type_a, sres_type_aaaa, sres_type_a6};
 	int i;
 
-	g_debug("%s: resolving %s:%u", G_STRFUNC, name, port);
-
 	data = idle_dns_query_data_new();
 
 	data->callback = callback;
@@ -384,10 +402,6 @@ void idle_dns_resolver_cancel_query(IdleDNSResolver *resolver, guint query_id)
 }
 #endif
 
-#include <sys/types.h>
-#include <sys/socket.h>
-#include <netdb.h>
-
 typedef struct _IdleDNSQueryData IdleDNSQueryData;
 
 struct _IdleDNSQueryData
@@ -462,7 +476,7 @@ _resolve_idle_func(struct _idle_helper *helper)
 	struct addrinfo *info = NULL;
 	struct addrinfo *cur;
 	int rc;
-	IdleDNSResult *results = NULL, *tail = NULL;
+	IdleDNSResultReal *results = NULL, *tail = NULL;
 	IdleDNSResultCallback cb;
 	gpointer user_data;
 	gchar *service = g_strdup_printf("%u", data->port);
@@ -474,14 +488,14 @@ _resolve_idle_func(struct _idle_helper *helper)
 
 	if (rc)
 	{
-		g_debug("%s: getaddrinfo(): %s", G_STRFUNC, gai_strerror(rc));
+		IDLE_DEBUG("getaddrinfo(): %s", gai_strerror(rc));
 		return FALSE;
 	}
 
 	for (cur = info; cur != NULL; cur = cur->ai_next)
 	{
-		IdleDNSResult *result = idle_dns_result_new();
-		g_debug("%s: got result with family %u", G_STRFUNC, cur->ai_family);
+		IdleDNSResultReal *real = idle_dns_result_real_new();
+    IdleDNSResult *result = &(real->result);
 
 		result->ai_family = cur->ai_family;
 		result->ai_socktype = cur->ai_socktype;
@@ -490,22 +504,24 @@ _resolve_idle_func(struct _idle_helper *helper)
 		result->ai_addrlen = cur->ai_addrlen;
 		result->ai_next = NULL;
 
+    real->addrinfo = NULL;
+
 		if (tail)
 		{
-			tail->ai_next = result;
+			tail->result.ai_next = (IdleDNSResult *)(real);
 		}
 
 		if (!results)
 		{
-			results = result;
+			results = real;
+      real->addrinfo = info;
 		}
 
-		tail = result;
+		tail = real;
 	}
 
 	g_hash_table_remove(helper->res->queries, GUINT_TO_POINTER(helper->serial));
-	cb(helper->serial, results, user_data);
-	freeaddrinfo(info);
+	cb(helper->serial, (IdleDNSResult *)(results), user_data);
 	g_free(service);
 
 	return FALSE;
@@ -556,7 +572,7 @@ idle_dns_resolver_cancel_query(IdleDNSResolver *res, guint id)
 
 	if (!data)
 	{
-		g_debug("%s query %u not found!", G_STRFUNC, id);
+		IDLE_DEBUG("query %u not found!", id);
 		return;
 	}
 
